Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(590)

Unified Diff: net/base/x509_util.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/base/ssl_config_service.cc ('k') | net/base/x509_util_nss.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/base/x509_util.h
diff --git a/net/base/x509_util.h b/net/base/x509_util.h
index 825ee023296ea1c13cc0f4f2a9b70b0f7865e05d..4c07b252024b7febbe96eaa1726da21cc24a07c2 100644
--- a/net/base/x509_util.h
+++ b/net/base/x509_util.h
@@ -19,19 +19,20 @@ namespace net {
namespace x509_util {
// Creates an origin bound certificate containing the public key in |key|.
// Web origin, serial number and validity period are given as
// parameters. The certificate is signed by the private key in |key|.
// The hashing algorithm for the signature is SHA-1.
//
// See Internet Draft draft-balfanz-tls-obc-00 for more details:
// http://tools.ietf.org/html/draft-balfanz-tls-obc-00
-bool NET_EXPORT_PRIVATE CreateOriginBoundCertEC(crypto::ECPrivateKey* key,
- const std::string& origin,
- uint32 serial_number,
- base::Time not_valid_before,
- base::Time not_valid_after,
- std::string* der_cert);
+bool NET_EXPORT_PRIVATE CreateDomainBoundCertEC(
+ crypto::ECPrivateKey* key,
+ const std::string& domain,
+ uint32 serial_number,
+ base::Time not_valid_before,
+ base::Time not_valid_after,
+ std::string* der_cert);
} // namespace x509_util
« no previous file with comments | « net/base/ssl_config_service.cc ('k') | net/base/x509_util_nss.cc » ('j') | no next file with comments »
@@ -19,19 +19,20 @@ namespace net {
namespace x509_util {
-// Creates an origin bound certificate containing the public key in |key|.
-// Web origin, serial number and validity period are given as
+// Creates a server bound certificate containing the public key in |key|.
+// Domain, serial number and validity period are given as
// parameters. The certificate is signed by the private key in |key|.
// The hashing algorithm for the signature is SHA-1.

Powered by Google App Engine
This is Rietveld 408576698